#
#                              Graphs  Rules
#_______________________________________________________________________________ 
#Figures should be drawn to publication quality (>300dpi) and to fit into a single column width (7 cm)
#wherever possible (maximum page length is 15cm).To make best use of space, you may need to rearrange parts of figures.
#Please ensure that axes, tick marks, symbols and labels are large enough to allow reduction to
#a final size of  > 8 point (i.e. capital letters should be c. 2mm tall). Legend should pe placed top left. Figures should not be boxed
#and tick marks should be on the inside of the axes. Lettering should use a sans serif font (e.g.
#Helvetica, Arial) with capitals used for the initial letter of the first word only. Bold lettering
#should not be used. Units of axes should appear in parentheses after the axis name. Manuscript should contain no more than 3 Figures.
#
#                                Working Directory
#_______________________________________________________________________________
###Changez pour votre propre rpertoire de travail
setwd("C:\\Documents and Settings\\chroy203\\Bureau")
#
#                               Load Library
#_______________________________________________________________________________
library(R2WinBUGS)
library(lme4)
#
#                               Import DATA
#_______________________________________________________________________________
data1<-read.table("data1.txt",header=TRUE, sep=";")
#Site                 # numros du site o l'oiseau a t captur
#Bird                 # numros de l'oiseau
#WingL                # mesure de l'aile  en cm
#TailL                # longeur de la queue  en cm
#Class_Forest         # Densit du couvert forstier
data2<- read.table("wtmatrix.csv",header=TRUE,sep=",",na.strings=c("NA"))
#y.1      presence/absence paruline inventaire #1 (pas utilis)
#y.2      presence/absence paruline inventaire #2 (pas utilis)
#y.3      presence/absence paruline inventaire #2 (pas utilis)
#c.1      abondance paruline inventaire #1 
#c.2      abondance paruline inventaire #2
#c.3      abondance paruline inventaire #3
#elev     lvation du transect
#forest   quantit de fort dans le paysage
#dur.1    dure du transect inventaire #1
#dur.2    dure du transect inventaire #2
#dur.3    dure du transect inventaire #3
#day.1    date de l'inventaire #1 en jour julien
#day.2    date de l'inventaire #2 en jour julien
#day.3    date de l'inventaire #3 en jour julien
#
#                               Transform DATA 
#_______________________________________________________________________________
High<-data1[data1$Class_Forest=="High", ]
Med<-data1[data1$Class_Forest=="Med", ]
Low<-data1[data1$Class_Forest=="Low", ]
#
#                               Analyze data
#_______________________________________________________________________________
WingLength<-glm(WingL~Class_Forest,data1, family=gaussian)
#WingLength2<-lmer(WingL~Class_Forest+(1|Site),data1, familly=gaussian, verbose=TRUE)
#WingLength3<-lmer(WingL~Class_Forest+(Class_Forest|Site),data1, familly=gaussian, verbose=TRUE)
summary(WingLength) # keep this one since AIC is smaller
#summary(WingLength2)
#summary(WingLength3)

TailLength<-glm(TailL~Class_Forest,data1, family=gaussian)
#TailLength2<-lmer(TailL~Class_Forest+(1|Site),data1, familly=gaussian, verbose=TRUE)
#TailLength3<-lmer(TailL~Class_Forest+(Class_Forest|Site),data1, familly=gaussian, verbose=TRUE)
summary(TailLength) # keep this one since AIC is smaller
#summary(TailLength2)
#summary(TailLength3)
#
#                              Vectorize ouput of estimates
#_______________________________________________________________________________
##Wing
##Form (Estimate, IC95Down, IC95UP)
Wing_High<-c(66.66890, 66.66890-(0.09446*1.96), 66.66890+(0.09446*1.96))
Wing_Med<-c((Wing_High[1]- 0.55617), ((Wing_High[1]- 0.55617)-(0.12895*1.96)), ((Wing_High[1]- 0.55617)+(0.12895*1.96)))
Wing_Low<-c((Wing_High[1]-1.38153), ((Wing_High[1]-1.38153)-(0.12764*1.96)), ((Wing_High[1]-1.38153)+(0.12764*1.96)))

##Tail
##Form (Estimate, IC95Down, IC95UP)
Tail_High<-c(62.5152, 62.5152-(0.1079*1.96), 62.5152+(0.1079*1.96))
Tail_Med<-c((Tail_High[1]-0.9083), ((Tail_High[1]-0.9083)-(0.1472*1.96)), ((Tail_High[1]-0.9083)+(0.1472*1.96)))
Tail_Low<-c((Tail_High[1]-2.0881), ((Tail_High[1]-2.0881)-(0.1458*1.96)), ((Tail_High[1]-2.0881)+(0.1458*1.96)))


#Create Quantile values wing
QH_Wing<-(c((quantile(High$WingL,probs =.025)),(quantile(High$WingL,probs =.975)))) 
QM_Wing<-(c((quantile(Med$WingL,probs =.025)),(quantile(Med$WingL,probs =.975))))
QL_Wing<-(c((quantile(Low$WingL,probs =.025)),(quantile(Low$WingL,probs =.975))))

#Create Quantile values tail
QH_Tail<-(c((quantile(High$TailL,probs =.025)),(quantile(High$TailL,probs =.975)))) 
QM_Tail<-(c((quantile(Med$TailL,probs =.025)),(quantile(Med$TailL,probs =.975))))
QL_Tail<-(c((quantile(Low$TailL,probs =.025)),(quantile(Low$TailL,probs =.975))))
#
#                              Graph for analysis 1
#_______________________________________________________________________________
###Nom de l'axe y pour analyse 1
####Crer  graphqiues de la taille des ailes et de la queue en fonction des groupes 
yaxis1a<-"Length of the wing (cm)"
yaxis1b<-"Length of the tail (cm)" 
 
#
#                               Transform DATA 2
#_______________________________________________________________________________
ymat<-as.matrix(data2[,c("c.1","c.2","c.3")])
elev<-as.vector(data2[,"elev"])
forest<-as.vector(data2[,"forest"])
length<-as.vector(data2[,"length"])

elev = (elev-mean(elev,na.rm=T))/sd(elev, na.rm=T)             #Centre et rduit les donnes
forest = (forest-mean(forest,na.rm=T))/sd(forest,na.rm=T)      #Centre et rduit les donnes

date<-as.matrix(data2[,c("day.1","day.2","day.3")])
mdate<-mean(date,na.rm=TRUE)
sddate<-sqrt(var(date[1:length(date)],na.rm=TRUE))          #Centre et rduit les donnes
date<-(date-mdate)/sddate                                   #Centre et rduit les donnes

date2<-date*date
elev2<-elev*elev

dur<-as.matrix(data2[,c("dur.1","dur.2","dur.3")])
intensity<-dur/length                                      #Intensit = dure prise pour faire le transect/ longueur
mint<-mean(intensity,na.rm=TRUE)
sdint<-sqrt(var(intensity[1:length(intensity)],na.rm=TRUE))
intensity<-(intensity-mint)/sdint                             #Centre et rduit les donnes

length<- (length-mean(length))/sqrt(var(length))             #Centre et rduit les donnes

### vectorize matrices to eliminate missing values
nsites = dim(ymat)[1]
nrepls = dim(ymat)[2]
site = rep(1:nsites, nrepls)
y = as.vector(ymat)
ymax = apply(ymat,1,max, na.rm=T)
intensity = as.vector(intensity)
date = as.vector(date)
date2 = as.vector(date2)
notmiss = !is.na(y)
site = site[notmiss]
y = y[notmiss]
intensity = intensity[notmiss]
date = date[notmiss]
date2 = date2[notmiss]
#
#                               Create Ouput for Winbugs
#_______________________________________________________________________________
### model specification in WinBUGS
####Modlise l'effet de l'intensit d'chantillonage et de la date sur la dtection 
####Et l'effet de l'lvation, de la quantit de fort et de la longeur des transects sur l'occurence de la paruline borale
####On utilise un modle aves surdispesion puisque les donnes ne respectent pas la dist. de Poisson

modelFilename = "wtitBayes2.txt"

  cat("
model {

###  priors
for (k in 1:5) {
  beta[k] ~ dnorm(0,.01)
}
alpha1Prec <- 1/pow(1.6,2)
alpha[1] ~ dnorm(0,alpha1Prec)
for (k in 2:4) {
  alpha[k] ~ dnorm(0,.01)
}
sigma ~ dunif(0,10)
bPrec <- pow(sigma,-2)

### abundance model
for (i in 1:nsites) {
  N[i] ~ dpois(lambda[i])
  log(lambda[i]) <- beta[1] + beta[2]*elev[i] + beta[3]*elev2[i] + beta[4]*forest[i] + beta[5]*length[i] + b[i]
  b[i] ~ dnorm(0,bPrec)
}

### observation model
for (j in 1:nobs) {
  eta[j] <- alpha[1] + alpha[2]*intensity[j] + alpha[3]*date[j] + alpha[4]*date2[j]
  p[j] <- 1 / (1 + exp(-eta[j]))
  y[j] ~ dbin(p[j], N[site[j]])
}

}
", fill=TRUE, file=modelFilename)


### arguments for bugs()
data = list(nsites=nsites, nobs=length(y), y=y, site=site, intensity=intensity, date=date, date2=date2,
  elev=elev, elev2=elev2, forest=forest, length=length)

params = list('alpha','beta','sigma')


inits = function() {
  list(alpha = rnorm(4), beta=rnorm(5), N=ymax+1, sigma=runif(1,0,2))
}
#
#                               Call Winbugs and see ouput
#_______________________________________________________________________________
###Cette fontion requiert que Winbugs soit install sur votre ordinateur
###En raison du nombre d'itrations le dlai d'attente est plutt long ">30 min"
###Fates la tourner en dernier recours
#
# call to bugs()
#fit = bugs(data, inits, params, model.file=modelFilename, program="OpenBUGS", 
#  n.chains=1, n.iter=60000, n.burnin=10000, n.thin=5, bugs.seed=sample(1:9999,size=1), debug=FALSE, DIC=FALSE)
#
#fit
#
#                              Vectorize ouput of estimates 2
#_______________________________________________________________________________

###extract estimates  form : (Estimate, 0.025IC, 0.975IC)
###Il y a deux modle distinct: un pour la probabilit de dtection (a) et un pour l'abondance (b)
### Seul les estims dont l'intervalle de confiance ne comnprenent pas zro ont un effet significatif
a0<-c           (-1.065, -1.822, -0.308)      #Intercepte de l'abondance
a_intensity<-c  ( 0.256, -0.125,  0.638)      #Effet de l'intensit de l'effort d'inventaire sur la prob. de dtection 
a_date<-c       (-0.211, -0.379, -0.043)      #Effet de la date d'inventaire sur la prob. de dtection
a_date2<-c      ( 0.088, -0.022,  0.197)      #Effet quadratique de la date d'inventaire sur la prob. de dtection
b0<-c           (-0.228, -0.935,  0.279)      #Intercepte de l'occupation
b_elev<-c       ( 2.409,  1.854,  2.693)      #Effet de l'lvation sur le nombre de paruline dtecte
b_elev2<-c      (-1.051, -1.548, -0.654)      #Effet quadratique de l'lvation sur le nombre de paruline prsentes
b_forest<-c     ( 0.922,  0.541,  1.303)      #Effet de la quantit de fort dans le paysage sur le nombre de paruline prsentes
b_length<-c     ( 0.390,  0.033,  0.748)      #Effet de la longueur du transect sur le nombre de paruline prsentes
s0<-c           ( 1.444,  1.086,  1.803)      #Paramtre de surdispersion pour la rgression (pas utilis pour les graphiques)


###extract mean for each parameter: utilis pour estimer la valeur des rgression
avg_intensity<-mean(intensity)
avg_date<-mean(date)
avg_date2<-mean(date2)
avg_elev<-mean(elev)
avg_elev2<-mean(elev2)
avg_forest<-mean(forest)
avg_length<-mean(length)

###create vector of predicted values for graph: permet de crer des variables prdites dans l'ordre
seq_date<-seq(min(date),max(date), by = 0.10)
seq_elev<-seq(min(elev), max(elev), by = 0.10)                                      
seq_elev2<-seq_elev*seq_elev                                      
seq_forest<-seq(min(forest),max(forest), by = 0.10)
seq_length<-seq(min(length),max(length), by = 0.10)


###Calulate values for graph: Calcul de la rgression 
###forme:
###est_: valeur de la rgression selon l'output
###down_: valeur infrieur de l'intervalle  IC95%
###up_: valeur suprieure de l'intervalle  IC95%


##detection
###Seul la valeur Date a un effet significatif; valeur de date^2=0 car la valeur est non significative (pas d'effet quadratique) 
est_date<-exp(a0[1] +  a_intensity[1]*avg_intensity + a_date[1]*seq_date + a_date2[1]*0)
down_date<- exp(a0[2] +  a_intensity[2]*avg_intensity + a_date[2]*seq_date + a_date2[2]*0)
up_date<-exp(a0[3] +  a_intensity[3]*avg_intensity + a_date[3]*seq_date + a_date2[3]*0)

#abundance
#### Effet de l'lvation
est_elev<-exp(b0[1] +  b_elev[1]*seq_elev + b_elev2[1]*seq_elev2 +  b_forest[1]*avg_forest + b_length[1]* avg_length)
down_elev<-exp(b0[2] +  b_elev[2]*seq_elev + b_elev2[2]*seq_elev2 +  b_forest[1]*avg_forest + b_length[1]* avg_length) 
up_elev<-exp(b0[3] +  b_elev[3]*seq_elev + b_elev2[3]*seq_elev2 +  b_forest[1]*avg_forest + b_length[1]* avg_length) 

#### Effet de la quantit de fort dans le paysage 
est_forest<-exp(b0[1] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[1]*seq_forest + b_length[1]* avg_length)
down_forest<-exp(b0[2] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[2]*seq_forest + b_length[1]* avg_length)
up_forest<-exp(b0[3] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[3]*seq_forest + b_length[1]* avg_length)


### Effet de la longeur des transects 
est_length<-exp(b0[1] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[1]*avg_forest + b_length[1]*seq_length)
down_length<-exp(b0[2] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[1]*avg_forest + b_length[2]*seq_length)
up_length<-exp(b0[3] +  b_elev[1]*avg_elev + b_elev2[1]*avg_elev2 +  b_forest[1]*avg_forest + b_length[3]*seq_length)

#
#                              Graphs
#_______________________________________________________________________________ 
###Nom de l'axe y pour rgression  2 
yaxis2a<-"Predicted probability of detecting a signing male (%)"
yaxis2b<-"Predicted occurence of signing males (birds)"
####Crer  graphqiues de la dtection et de l'abondance en fonction des paramtres significatifs
### x axis will vary in function of regression
### units:
###date(days)
###elev(m)
###fort(%)
###transect(km)



